pub enum Arg {
ExprCast(ExprCast),
Expr(Expr),
}Expand description
An argument to a pw_format backed macro.
pw_format backed macros have special case recognition of type casts
(value as ty) in order to annotate a type for typeless printing w/o
relying on experimental features. If an argument is given in that form,
it will be represented as an Arg::ExprCast here. Otherwise it will
be an Arg::Expr.
Variants
ExprCast(ExprCast)
An argument that is an type cast expression.
Expr(Expr)
An argument that is an expression.