FormatString

Struct FormatString 

pub struct FormatString {
    pub fragments: Vec<FormatFragment>,
}
A parsed format string.

Fields

fragments: Vec<FormatFragment>

The FormatFragments that comprise the FormatString.

Implementations

Source

impl FormatString

pub fn format(&self, args: &[Arg], style: FormatStyle) -> String

Formats a parsed format string with provided arguments.

pub fn format_with_errors<FE: FormatError>( &self, args: &[Result<Arg, FE::Error>], style: FormatStyle, error_formatter: &FE, ) -> String

Formats a parsed format string with the provided argument states (Result<Arg, FE::Error>), delegating formatting of any failures, missing arguments, or type mismatches to the provided FormatError implementation.

pub fn parse_printf(s: &str) -> Result<Self, String>

Parses a printf style format string.

pub fn parse_core_fmt(s: &str) -> Result<Self, String>

Parses a core::fmt style format string.